@@ -35,16 +35,19 @@ MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow)
 {
+    process = NULL;
+    triggerCount = 0;
+    volumeMeterWidget = NULL;
+
     QCoreApplication::setOrganizationName("VU Meter");
     QCoreApplication::setOrganizationDomain("https://garage.maemo.org/projects/vumeter");
     QCoreApplication::setApplicationName("VU Meter");
 
+    QSettings settings;
+    meter = settings.value(SettingsDialog::METER, 0).toInt();
+
     ui->setupUi(this);
 
-    process = NULL;
-    meter = 0;
-    triggerCount = 0;
-    volumeMeterWidget = NULL;
     changeMeter();
 
     setDbScale();
@@ -90,6 +93,10 @@ MainWindow::MainWindow(QWidget *parent) :
 
 MainWindow::~MainWindow()
 {
+    QSettings settings;
+    settings.setValue(SettingsDialog::METER, meter);
+    settings.sync();
+
     delete ui;
 
     if(process != NULL){
@@ -125,11 +132,11 @@ void MainWindow::changeMeter(){
 
     volumeMeterWidget->setDbUnit(ui->radioButtonDb->isChecked());
     ui->volumeMeterLayout->addWidget(volumeMeterWidget);
-    getSettings();
+    applySettings();
     connect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
 }
 
-void MainWindow::getSettings(){
+void MainWindow::applySettings(){
     QSettings settings;
     triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt();
     triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString();
@@ -142,6 +149,11 @@ void MainWindow::getSettings(){
 
     volumeMeterWidget->setTriggerValue(triggerValue);
     volumeMeterWidget->setUseColoredScale(settings.value(SettingsDialog::COLOR_SCALE, false).toBool());
+    volumeMeterWidget->setColors(settings.value(SettingsDialog::COLOR_LOWER_COLOR, QColor(Qt::green)).value<QColor>(),
+                                 settings.value(SettingsDialog::COLOR_MID_COLOR, QColor(Qt::yellow)).value<QColor>(),
+                                 settings.value(SettingsDialog::COLOR_UPPER_COLOR, QColor(Qt::red)).value<QColor>());
+    volumeMeterWidget->setColorThresholds(settings.value(SettingsDialog::COLOR_LOWER_THRESHOLD, 60).toInt(),
+                                          settings.value(SettingsDialog::COLOR_UPPER_THRESHOLD, 95).toInt());
 }
 
 void MainWindow::processFinished(){
@@ -160,7 +172,7 @@ void MainWindow::settingsDialog(){
     SettingsDialog dialog(this);
 
     if(dialog.exec()){
-        getSettings();
+        applySettings();
     }
 }
 
