@@ -59,7 +59,7 @@ private:
 
     VolumeMeterWidget *volumeMeterWidget;
 
-    void getSettings();
+    void applySettings();
 
 private slots:
     void processFinished();
