@@ -20,6 +20,7 @@
 #ifndef VOLUMEMETERWIDGET_H
 #define VOLUMEMETERWIDGET_H
 
+#include <QColor>
 #include <QImage>
 #include <QPainter>
 #include <QtOpenGL/QGLWidget>
@@ -38,20 +39,30 @@ public:
     virtual void updateValue(int value);
     virtual void setDbUnit(bool b);
     virtual void setTriggerValue(int value);
+
+    void setColors(QColor lower, QColor mid, QColor upper);
+    void setColorThresholds(int lower, int upper);
     void setUseColoredScale(bool b);
 
 signals:
     void clicked();
 
 protected:
-    QImage *background;
-    int currentValue;
-    bool dbUnit;
-    float h;
+    QImage          *background;
+    int             currentValue;
+    bool            dbUnit;
+    float           h;
     Qt::GlobalColor triggerIndicatorColor;
-    int triggerValue;
-    bool useColoredScale;
-    float w;
+    int             triggerValue;
+    bool            useColoredScale;
+    float           w;
+
+    int             lowerThreshold;
+    int             upperThreshold;
+
+    QColor          lowerColor;
+    QColor          midColor;
+    QColor          upperColor;
 
     virtual void calculateSize();
 
